from setuptools import setup, find_packages

#get the long description from the README file
long_description = "Testing the packaging process"

setup(
    name ="MbaliHelloPkg",
    version ="1.0.0",
 description="A sample of python Hello world",
long_description=long_description,
author = "Mbali Python",
author_email="mbaliphama8@gmail.com",
classifier = [
"development status::1- Planning",
    "Intended audience::Developers",
    "Topic::Software  Development::Build Tools",
    "License :: OSI Approved;;MIT License",
    "Programming Language ::Python::3",
    "Operating System::Microsoft::Windows",
    
   ],
)
 
